@@ -1,6 +1,6 @@
 # Copyright (C) 2011 Lukas Lalinsky
 # (Minor modifications by Adrian Sampson.)
-# Distributed under the MIT license, see the LICENSE file for details. 
+# Distributed under the MIT license, see the LICENSE file for details.
 
 """Low-level ctypes wrapper from the chromaprint library."""
 
@@ -8,16 +8,24 @@ import sys
 import ctypes
 
 
+if sys.version_info[0] >= 3:
+    BUFFER_TYPES = (memoryview,)
+elif sys.version_info[1] >= 7:
+    BUFFER_TYPES = (buffer, memoryview,)
+else:
+    BUFFER_TYPES = (buffer,)
+
+
 # Find the base library and declare prototypes.
 
 def _guess_lib_name():
     if sys.platform == 'darwin':
-        return ('libchromaprint.0.dylib',)
+        return ('libchromaprint.1.dylib', 'libchromaprint.0.dylib')
     elif sys.platform == 'win32':
         return ('chromaprint.dll', 'libchromaprint.dll')
     elif sys.platform == 'cygwin':
-        return ('libchromaprint.dll.a', 'cygchromaprint-0.dll')
-    return ('libchromaprint.so.0',)
+        return ('libchromaprint.dll.a', 'cygchromaprint-1.dll', 'cygchromaprint-0.dll')
+    return ('libchromaprint.so.1', 'libchromaprint.so.0')
 
 for name in _guess_lib_name():
     try:
@@ -105,10 +113,10 @@ class Fingerprinter(object):
         """Send raw PCM audio data to the fingerprinter. Data may be
         either a bytestring or a buffer object.
         """
-        if isinstance(data, buffer):
+        if isinstance(data, BUFFER_TYPES):
             data = str(data)
-        elif not isinstance(data, str):
-            raise TypeError('data must be str or buffer')
+        elif not isinstance(data, bytes):
+            raise TypeError('data must be bytes, buffer, or memoryview')
         _check(_libchromaprint.chromaprint_feed(
             self._ctx, data, len(data) // 2
         ))
